package com.greenorange.promotion.model.dto.user;

import io.swagger.v3.oas.annotations.media.Schema;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.NotNull;
import java.io.Serial;
import java.io.Serializable;

/**
 * 用户添加请求体
 */
@Data
@Schema(description = "用户表添加请求体", requiredProperties = {"nickName", "userAvatar", "phoneNumber",
        "userAccount", "userPassword", "invitationCode", "userRole", "parentUserId", "superUserList"})
public class UserInfoAddRequest implements Serializable {

    /**
     * 用户昵称
     */
    @NotBlank(message = "参数不能为空")
    @Schema(description = "用户昵称", example = "${field.example}")
    private String nickName;

    /**
     * 用户头像URL
     */
    @Schema(description = "用户头像URL", example = "${field.example}")
    private String userAvatar;

    /**
     * 手机号
     */
    @NotBlank(message = "参数不能为空")
    @Schema(description = "手机号", example = "${field.example}")
    private String phoneNumber;

    /**
     * 账号
     */
    @NotBlank(message = "参数不能为空")
    @Schema(description = "账号", example = "${field.example}")
    private String userAccount;

    /**
     * 密码
     */
    @NotBlank(message = "参数不能为空")
    @Schema(description = "密码", example = "${field.example}")
    private String userPassword;

    /**
     * 邀请码
     */
    @Schema(description = "邀请码", example = "${field.example}")
    private String invitationCode;

    /**
     * 用户角色
     */
    @NotBlank(message = "参数不能为空")
    @Schema(description = "用户角色", example = "${field.example}")
    private String userRole;

    /**
     * 上级用户id
     */
    @Schema(description = "上级用户id", example = "${field.example}")
    private Long parentUserId;

    /**
     * 上级用户列表（1,2,3）
     */
    @Schema(description = "上级用户列表（1,2,3）", example = "${field.example}")
    private String superUserList;


    @Serial
    private static final long serialVersionUID = 1L;
}
